@@ -1,15 +1,12 @@
 use anyhow::Error;
 use chrono::NaiveDate;
 use num_bigint::BigInt;
-use odbc_api::{
-    sys::{Date, Timestamp},
-    Bit,
-};
+use odbc_api::sys::Timestamp;
 use parquet::{
     column::{reader::ColumnReaderImpl, writer::ColumnWriterImpl},
     data_type::{ByteArray, DataType, FixedLenByteArray, FixedLenByteArrayType, Int64Type},
 };
-use std::{convert::TryInto, mem::size_of};
+use std::mem::size_of;
 
 /// Holds preallocated buffers for every possible physical parquet type. This way we do not need to
 /// reallocate them.
@@ -72,7 +69,7 @@ impl ParquetBuffer {
         digits.clear();
         digits.extend(decimal.iter().filter(|&&c| c != b'.'));
 
-        let (num, _consumed) = i128::from_radix_10_signed(&digits);
+        let (num, _consumed) = i128::from_radix_10_signed(digits);
 
         let out = num.to_be_bytes()[(16 - length)..].to_owned();
         // Vec<u8> -> ByteArray -> FixedLenByteArray
@@ -91,7 +88,7 @@ impl ParquetBuffer {
         digits.clear();
         digits.extend(decimal.iter().filter(|&&c| c != b'.'));
 
-        let (num, _consumed) = BigInt::from_radix_10_signed(&digits);
+        let (num, _consumed) = BigInt::from_radix_10_signed(digits);
         let mut out = num.to_signed_bytes_be();
 
         let num_leading_bytes = length - out.len();
@@ -185,17 +182,16 @@ impl ParquetBuffer {
     /// Write to a parquet buffer using an iterator over optional source items. A default
     /// transformation, defined via the `IntoPhysical` trait is used to transform the items into
     /// buffer elements.
-    pub fn write_optional<T, S>(
+    pub fn write_optional<T>(
         &mut self,
         cw: &mut ColumnWriterImpl<T>,
-        source: impl Iterator<Item = Option<S>>,
+        source: impl Iterator<Item = Option<T::T>>,
     ) -> Result<(), Error>
     where
         T: DataType,
         T::T: BufferedDataType,
-        S: IntoPhysical<T::T>,
     {
-        self.write_optional_any(cw, source, |s| s.into_physical())
+        self.write_optional_any(cw, source, |s| s)
     }
 
     /// Iterate over the elements of a column reader over an optional column.
@@ -313,54 +309,6 @@ impl BufferedDataType for FixedLenByteArray {
     }
 }
 
-pub trait IntoPhysical<T> {
-    fn into_physical(self) -> T;
-}
-
-impl<T> IntoPhysical<T> for &T
-where
-    T: Copy,
-{
-    fn into_physical(self) -> T {
-        *self
-    }
-}
-
-impl IntoPhysical<i32> for &Date {
-    fn into_physical(self) -> i32 {
-        let unix_epoch = NaiveDate::from_ymd(1970, 1, 1);
-        // Transform date to days since unix epoch as i32
-        let date = NaiveDate::from_ymd(self.year as i32, self.month as u32, self.day as u32);
-        let duration = date.signed_duration_since(unix_epoch);
-        duration.num_days().try_into().unwrap()
-    }
-}
-
-impl IntoPhysical<bool> for &Bit {
-    fn into_physical(self) -> bool {
-        self.as_bool()
-    }
-}
-
-impl IntoPhysical<ByteArray> for String {
-    fn into_physical(self) -> ByteArray {
-        self.into_bytes().into()
-    }
-}
-
-impl IntoPhysical<ByteArray> for &[u8] {
-    fn into_physical(self) -> ByteArray {
-        self.to_owned().into()
-    }
-}
-
-impl IntoPhysical<FixedLenByteArray> for &[u8] {
-    fn into_physical(self) -> FixedLenByteArray {
-        let byte_array: ByteArray = self.to_owned().into();
-        byte_array.into()
-    }
-}
-
 #[cfg(test)]
 mod test {
 
